Module bootstrap

Module bootstrap 

Bootstrap engine for automatic module discovery and server setup

This module provides the core bootstrap functionality that enables the Laravel/NestJS-style one-line app initialization:

#[elif::main]
async fn main() -> Result<(), ElifError> {
    AppModule::bootstrap().listen("127.0.0.1:3000").await
}

Re-exports

pub use app_module::*;
pub use controller_registry::*;
pub use controllers::*;
pub use engine::*;
pub use route_validator::*;

Modules

app_module
AppBootstrap trait and bootstrap implementation for app modules
controller_registry
Controller Type Registry for runtime controller resolution
controllers
Controller auto-registration system for zero-boilerplate controller setup
engine
Bootstrap engine that orchestrates module discovery, dependency resolution, container configuration, and server startup.
route_validator
Route conflict detection and validation system for bootstrap integration