Module database

Database Integration - Service providers for database connectivity

Provides service providers for PostgreSQL connection pooling and ORM integration with the DI container system.

Structs

DatabaseServiceProvider
Database service provider for PostgreSQL connection pool

Functions

create_database_pool
Helper function to create a database pool directly
get_database_pool
Helper function to get database pool from container (for future implementation)
get_named_database_pool
Helper function to get custom named database pool from container (for future implementation)