Database Integration - Service providers for database connectivity
Provides service providers for PostgreSQL connection pooling and ORM integration with the DI container system.
Structs
- Database
Service Provider - Database service provider for PostgreSQL connection pool
Functions
- create_
database_ pool - Helper function to create a database pool directly
- get_
database_ pool - Helper function to get database pool from container (for future implementation)
- get_
named_ database_ pool - Helper function to get custom named database pool from container (for future implementation)